@@ -9,7 +9,9 @@ with 'TableDataRole::Source::CSVInDATA';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-05'; # DATE
 our $DIST = 'TableData-Chemistry-Element'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
+
+our %STATS = ("num_rows",118,"num_columns",17); # STATS
 
 1;
 # ABSTRACT: Chemical elements
@@ -24,7 +26,48 @@ TableData::Chemistry::Element - Chemical elements
 
 =head1 VERSION
 
-This document describes version 0.001 of TableData::Chemistry::Element (from Perl distribution TableData-Chemistry-Element), released on 2023-02-05.
+This document describes version 0.002 of TableData::Chemistry::Element (from Perl distribution TableData-Chemistry-Element), released on 2023-02-05.
+
+=head1 SYNOPSIS
+
+To use from Perl code:
+
+ use TableData::Chemistry::Element;
+
+ my $td = TableData::Chemistry::Element->new;
+
+ # Iterate rows of the table
+ $td->each_row_arrayref(sub { my $row = shift; ... });
+ $td->each_row_hashref (sub { my $row = shift; ... });
+
+ # Get the list of column names
+ my @columns = $td->get_column_names;
+
+ # Get the number of rows
+ my $row_count = $td->get_row_count;
+
+See also L<TableDataRole::Spec::Basic> for other methods.
+
+To use from command-line (using L<tabledata> CLI):
+
+ # Display as ASCII table and view with pager
+ % tabledata Chemistry::Element --page
+
+ # Get number of rows
+ % tabledata --action count_rows Chemistry::Element
+
+See the L<tabledata> CLI's documentation for other available actions and options.
+
+=head1 TABLEDATA STATISTICS
+
+ +-------------+-------+
+ | key         | value |
+ +-------------+-------+
+ | num_columns | 17    |
+ | num_rows    | 118   |
+ +-------------+-------+
+
+The statistics is available in the C<%STATS> package variable.
 
 =head1 HOMEPAGE
 
